#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 authenticate
version:              1.3.5.2
visibility:           public
id:                   authenticate-1.3.5.2-8FEYKp2wxqAKs3QP9LIX1Z
key:                  authenticate-1.3.5.2-8FEYKp2wxqAKs3QP9LIX1Z
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman, Hiromi Ishii, Arash Rouhani
stability:            Stable
homepage:             http://github.com/yesodweb/authenticate
synopsis:             Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.

category:             Web
abi:                  dbb1c4fa4eecb329fea5620e93b8158e
exposed:              True
exposed-modules:
    Web.Authenticate.BrowserId Web.Authenticate.OpenId
    Web.Authenticate.OpenId.Providers Web.Authenticate.Rpxnow

hidden-modules:
    Web.Authenticate.Internal OpenId2.Discovery OpenId2.Normalization
    OpenId2.Types OpenId2.XRDS

import-dirs:          /usr/lib/ghc-9.6.6/site-local/authenticate-1.3.5.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/authenticate-1.3.5.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/authenticate-1.3.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-authenticate
hs-libraries:         HSauthenticate-1.3.5.2-8FEYKp2wxqAKs3QP9LIX1Z
depends:
    aeson-2.2.2.0-Bvq1RZLTB982HJyF7e96XU
    attoparsec-0.14.4-9CcJCC4ORykBmnSiMZ6uwP
    attoparsec-aeson-2.2.0.1-GizRtDqX30r1GIBnmEuU50 base-4.18.2.1
    blaze-builder-0.4.4.1-1osLiMNDaK0LJVibZzd2na bytestring-0.11.5.3
    case-insensitive-1.2.1.0-8beqaZQCG6YFLwD8uR7pTp
    conduit-1.3.6.1-534uwm1BQ035a3x29nwuhR containers-0.6.7
    html-conduit-1.3.2.2-8wxMSr2VgjBjSueiniZ0m
    http-conduit-2.3.9.1-JcUtgfOUbxf5vdq2wc5MPb
    http-types-0.12.4-BfnwqLIFvgHNb88uBZwW9
    network-uri-2.6.4.2-DXIr6FO81fkKKSx83uC4Cz
    resourcet-1.2.6-5o8OKNGoLEyGu1zh0QIf5q text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-ITIVaOGw28dDFkmcPJu0s3
    xml-conduit-1.9.1.4-430IDrCsltvJcqEk0o9JzY

haddock-interfaces:
    /usr/share/doc/haskell-authenticate/html/authenticate.haddock

haddock-html:         /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

